Schaefer 2018 Atlas


Notes
-----
This atlas provides a labeling of cortical voxels in the MNI152
space, see Schaefer et al. (2018). Each ROI is annotated with a
network from the Yeo parcellation (7- or 17-network solution; see
Yeo et al., 2011).


Different versions of the atlas are available, varying in
- number of rois (100 to 1000),
- network annotation (7 or 17)
- spatial resolution of the atlas (1 or 2 mm)

Content
-------
    :'maps': 3D Nifti image, values are indices in the list of labels.
    :'labels': ROI labels including Yeo-network annotation.
    :'description': A short description of the atlas and some references.

References
----------
For more information on this dataset, see
https://github.com/ThomasYeoLab/CBIG/tree/v0.8.1-Schaefer2018_LocalGlobal/stable_projects/brain_parcellation/Schaefer2018_LocalGlobal

Schaefer A, Kong R, Gordon EM, Laumann TO, Zuo XN, Holmes AJ,
Eickhoff SB, Yeo BTT. Local-Global parcellation of the human
cerebral cortex from intrinsic functional connectivity MRI,
Cerebral Cortex, 29:3095-3114, 2018.

Yeo BT, Krienen FM, Sepulcre J, Sabuncu MR, Lashkari D, Hollinshead M,
Roffman JL, Smoller JW, Zollei L., Polimeni JR, Fischl B, Liu H,
Buckner RL. The organization of the human cerebral cortex estimated by
intrinsic functional connectivity. J Neurophysiol 106(3):1125-65, 2011.

Licence: MIT.
